#[repr(C)]pub struct InputDeviceGetInputReportsReaderV2Response {
pub max_unacknowledged_reports: u16,
}Fields
max_unacknowledged_reports: u16Trait Implementations
Sourceimpl Clone for InputDeviceGetInputReportsReaderV2Response
impl Clone for InputDeviceGetInputReportsReaderV2Response
Sourcefn clone(&self) -> InputDeviceGetInputReportsReaderV2Response
fn clone(&self) -> InputDeviceGetInputReportsReaderV2Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for InputDeviceGetInputReportsReaderV2Response
Sourceimpl<___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, InputDeviceGetInputReportsReaderV2Response>
const COPY_OPTIMIZATION: CopyOptimization<Self, InputDeviceGetInputReportsReaderV2Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for &'a InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for &'a InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, InputDeviceGetInputReportsReaderV2Response>, ___E> for InputDeviceGetInputReportsReaderV2Responsewhere
___E: Encoder + ?Sized,
InputDeviceGetInputReportsReaderV2Response: Encode<InputDeviceGetInputReportsReaderV2Response, ___E>,
impl<___E> EncodeOption<Box<'static, InputDeviceGetInputReportsReaderV2Response>, ___E> for InputDeviceGetInputReportsReaderV2Responsewhere
___E: Encoder + ?Sized,
InputDeviceGetInputReportsReaderV2Response: Encode<InputDeviceGetInputReportsReaderV2Response, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceGetInputReportsReaderV2Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceGetInputReportsReaderV2Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, InputDeviceGetInputReportsReaderV2Response>, ___E> for &'a InputDeviceGetInputReportsReaderV2Responsewhere
___E: Encoder + ?Sized,
&'a InputDeviceGetInputReportsReaderV2Response: Encode<InputDeviceGetInputReportsReaderV2Response, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, InputDeviceGetInputReportsReaderV2Response>, ___E> for &'a InputDeviceGetInputReportsReaderV2Responsewhere
___E: Encoder + ?Sized,
&'a InputDeviceGetInputReportsReaderV2Response: Encode<InputDeviceGetInputReportsReaderV2Response, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, InputDeviceGetInputReportsReaderV2Response>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, InputDeviceGetInputReportsReaderV2Response>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for InputDeviceGetInputReportsReaderV2Response
Sourceimpl FromWire<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
impl FromWire<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportsReaderV2Response, Self>
const COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportsReaderV2Response, Self>
Sourcefn from_wire(wire: InputDeviceGetInputReportsReaderV2Response) -> Self
fn from_wire(wire: InputDeviceGetInputReportsReaderV2Response) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
impl FromWireRef<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
Sourcefn from_wire_ref(wire: &InputDeviceGetInputReportsReaderV2Response) -> Self
fn from_wire_ref(wire: &InputDeviceGetInputReportsReaderV2Response) -> Self
Converts the given reference to this type.
Sourceimpl Ord for InputDeviceGetInputReportsReaderV2Response
impl Ord for InputDeviceGetInputReportsReaderV2Response
Sourcefn cmp(&self, other: &InputDeviceGetInputReportsReaderV2Response) -> Ordering
fn cmp(&self, other: &InputDeviceGetInputReportsReaderV2Response) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InputDeviceGetInputReportsReaderV2Response
impl PartialEq for InputDeviceGetInputReportsReaderV2Response
Sourcefn eq(&self, other: &InputDeviceGetInputReportsReaderV2Response) -> bool
fn eq(&self, other: &InputDeviceGetInputReportsReaderV2Response) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InputDeviceGetInputReportsReaderV2Response
impl PartialOrd for InputDeviceGetInputReportsReaderV2Response
Sourcefn partial_cmp(
&self,
other: &InputDeviceGetInputReportsReaderV2Response,
) -> Option<Ordering>
fn partial_cmp( &self, other: &InputDeviceGetInputReportsReaderV2Response, ) -> Option<Ordering>
impl StructuralPartialEq for InputDeviceGetInputReportsReaderV2Response