#[repr(C)]pub struct InputDeviceGetFeatureReportResponse<'de> {
pub report: FeatureReport<'de>,
}Expand description
The wire type corresponding to InputDeviceGetFeatureReportResponse.
Fields
report: FeatureReport<'de>Trait Implementations
Sourceimpl Constrained for InputDeviceGetFeatureReportResponse<'_>
impl Constrained for InputDeviceGetFeatureReportResponse<'_>
Sourceimpl<'de> Debug for InputDeviceGetFeatureReportResponse<'de>
impl<'de> Debug for InputDeviceGetFeatureReportResponse<'de>
Sourceimpl<'de, ___D> Decode<___D> for InputDeviceGetFeatureReportResponse<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
impl<'de, ___D> Decode<___D> for InputDeviceGetFeatureReportResponse<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
Sourceimpl<'a, ___E> Encode<InputDeviceGetFeatureReportResponse<'static>, ___E> for &'a InputDeviceGetFeatureReportResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<InputDeviceGetFeatureReportResponse<'static>, ___E> for &'a InputDeviceGetFeatureReportResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetFeatureReportResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetFeatureReportResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<InputDeviceGetFeatureReportResponse<'static>, ___E> for InputDeviceGetFeatureReportResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<InputDeviceGetFeatureReportResponse<'static>, ___E> for InputDeviceGetFeatureReportResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetFeatureReportResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetFeatureReportResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<InputDeviceGetFeatureReportResponse<'static>, ___E> for InputDeviceGetFeatureReportResponse<T0>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<FeatureReport<'static>, ___E>,
impl<___E, T0> Encode<InputDeviceGetFeatureReportResponse<'static>, ___E> for InputDeviceGetFeatureReportResponse<T0>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<FeatureReport<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetFeatureReportResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetFeatureReportResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<InputDeviceGetFeatureReportResponse<'de>> for InputDeviceGetFeatureReportResponse
impl<'de> FromWire<InputDeviceGetFeatureReportResponse<'de>> for InputDeviceGetFeatureReportResponse
Sourcefn from_wire(wire: InputDeviceGetFeatureReportResponse<'de>) -> Self
fn from_wire(wire: InputDeviceGetFeatureReportResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<InputDeviceGetFeatureReportResponse<'de>> for InputDeviceGetFeatureReportResponse
impl<'de> FromWireRef<InputDeviceGetFeatureReportResponse<'de>> for InputDeviceGetFeatureReportResponse
Sourcefn from_wire_ref(wire: &InputDeviceGetFeatureReportResponse<'de>) -> Self
fn from_wire_ref(wire: &InputDeviceGetFeatureReportResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for InputDeviceGetFeatureReportResponse<'de>
impl<'de> IntoNatural for InputDeviceGetFeatureReportResponse<'de>
Sourcetype Natural = InputDeviceGetFeatureReportResponse
type Natural = InputDeviceGetFeatureReportResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InputDeviceGetFeatureReportResponse<'static>
impl Wire for InputDeviceGetFeatureReportResponse<'static>
Sourcetype Narrowed<'de> = InputDeviceGetFeatureReportResponse<'de>
type Narrowed<'de> = InputDeviceGetFeatureReportResponse<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.