#[repr(C)]pub struct InputDeviceGetInputReportsReaderV2Response {
pub max_unacknowledged_reports: Uint16,
}Expand description
The wire type corresponding to InputDeviceGetInputReportsReaderV2Response.
Fields
max_unacknowledged_reports: Uint16Trait Implementations
Sourceimpl Clone for InputDeviceGetInputReportsReaderV2Response
impl Clone for InputDeviceGetInputReportsReaderV2Response
Sourcefn clone(&self) -> InputDeviceGetInputReportsReaderV2Response
fn clone(&self) -> InputDeviceGetInputReportsReaderV2Response
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for InputDeviceGetInputReportsReaderV2Response
impl Constrained for InputDeviceGetInputReportsReaderV2Response
Sourceimpl<___D> Decode<___D> for InputDeviceGetInputReportsReaderV2Responsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for InputDeviceGetInputReportsReaderV2Responsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, InputDeviceGetInputReportsReaderV2Response>
const COPY_OPTIMIZATION: CopyOptimization<Self, InputDeviceGetInputReportsReaderV2Response>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for &'a InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for &'a InputDeviceGetInputReportsReaderV2Responsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for InputDeviceGetInputReportsReaderV2Response<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
impl<___E, T0> Encode<InputDeviceGetInputReportsReaderV2Response, ___E> for InputDeviceGetInputReportsReaderV2Response<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<InputDeviceGetInputReportsReaderV2Response>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
impl FromWire<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
Sourceconst COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportsReaderV2Response, Self>
const COPY_OPTIMIZATION: CopyOptimization<InputDeviceGetInputReportsReaderV2Response, Self>
Sourcefn from_wire(wire: InputDeviceGetInputReportsReaderV2Response) -> Self
fn from_wire(wire: InputDeviceGetInputReportsReaderV2Response) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
impl FromWireRef<InputDeviceGetInputReportsReaderV2Response> for InputDeviceGetInputReportsReaderV2Response
Sourcefn from_wire_ref(wire: &InputDeviceGetInputReportsReaderV2Response) -> Self
fn from_wire_ref(wire: &InputDeviceGetInputReportsReaderV2Response) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for InputDeviceGetInputReportsReaderV2Response
impl IntoNatural for InputDeviceGetInputReportsReaderV2Response
Sourcetype Natural = InputDeviceGetInputReportsReaderV2Response
type Natural = InputDeviceGetInputReportsReaderV2Response
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for InputDeviceGetInputReportsReaderV2Response
impl Wire for InputDeviceGetInputReportsReaderV2Response
Sourcetype Narrowed<'de> = InputDeviceGetInputReportsReaderV2Response
type Narrowed<'de> = InputDeviceGetInputReportsReaderV2Response
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.